@@ -6,18 +6,24 @@ fn main() {
 
 fn root_command() -> Command {
 	Command::with_name("multi")
+		.description("root command sample: arg printer")
+		.usage(presets::usage("multi"))
 		.common_flag(Flag::new_bool("help").short_alias('h'))
 		.common_flag(Flag::new_bool("reverse").short_alias('r'))
-		.local_flag(Flag::new_bool("by-char").short_alias('c'))
+		.local_flag(
+			Flag::new_bool("by-char")
+				.short_alias('c')
+				.description("process at char units"),
+		)
 		.action(print_args)
 		.sub_command(add_command())
 		.sub_command(sub_command())
 }
 fn call_help(c: &Context, cur_cmd: &Command) -> Result<ActionResult, ActionError> {
-	println!("{}", presets::help(c, cur_cmd));
+	println!("{}", presets::func::help(cur_cmd, c));
 	done!()
 }
-fn print_args(context: Context, current_command: Command) -> Result<ActionResult, ActionError> {
+fn print_args(current_command: Command, context: Context) -> Result<ActionResult, ActionError> {
 	if called_help(&context, &current_command) {
 		return call_help(&context, &current_command);
 	}
@@ -59,7 +65,7 @@ fn add_command() -> Command {
 		.local_flag(Flag::new_bool("detail").short_alias('d'))
 }
 
-fn add_action(c: Context, cmd: Command) -> Result<ActionResult, ActionError> {
+fn add_action(cmd: Command, c: Context) -> Result<ActionResult, ActionError> {
 	if called_help(&c, &cmd) {
 		return call_help(&c, &cmd);
 	}
@@ -96,7 +102,7 @@ fn sub_command() -> Command {
 		.local_flag(Flag::new_bool("sort").short_alias('s'))
 }
 
-fn sub_action(c: Context, cmd: Command) -> Result<ActionResult, ActionError> {
+fn sub_action(cmd: Command, c: Context) -> Result<ActionResult, ActionError> {
 	if called_help(&c, &cmd) {
 		return call_help(&c, &cmd);
 	}
